package sun.security.acl;

import java.security.acl.Group;
import java.util.Enumeration;
import java.security.acl.Permission;
import java.util.Vector;
import java.security.Principal;
import java.security.acl.AclEntry;

public class AclEntryImpl implements AclEntry
{
    private Principal user;
    private Vector<Permission> permissionSet;
    private boolean negative;
    
    public AclEntryImpl(Principal user) {
        this.user = null;
        this.permissionSet = new Vector(10, 10);
        this.negative = false;
        this.user = user;
    }
    
    public AclEntryImpl() {
        this.user = null;
        this.permissionSet = new Vector(10, 10);
        this.negative = false;
    }
    
    public boolean setPrincipal(Principal user) {
        if (this.user != null) {
            return false;
        }
        this.user = user;
        return true;
    }
    
    public void setNegativePermissions() {
        this.negative = true;
    }
    
    public boolean isNegative() {
        return this.negative;
    }
    
    public boolean addPermission(Permission permission) {
        if (this.permissionSet.contains(permission)) {
            return false;
        }
        this.permissionSet.addElement(permission);
        return true;
    }
    
    public boolean removePermission(Permission obj) {
        return this.permissionSet.removeElement(obj);
    }
    
    public boolean checkPermission(Permission o) {
        return this.permissionSet.contains(o);
    }
    
    public Enumeration<Permission> permissions() {
        return this.permissionSet.elements();
    }
    
    @Override
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        if (this.negative) {
            buffer.append("-");
        }
        else {
            buffer.append("+");
        }
        if ((this.user instanceof Group)) {
            buffer.append("Group.");
        }
        else {
            buffer.append("User.");
        }
        buffer.append(this.user + "=");
        Enumeration<Permission> permissions = this.permissions();
        while (permissions.hasMoreElements()) {
            buffer.append((Object)permissions.nextElement());
            if (permissions.hasMoreElements()) {
                buffer.append(",");
            }
            else {
                continue;
            }
        }
        return new String(buffer);
    }
    
    public synchronized Object clone() {
        AclEntryImpl aclEntryImpl = new AclEntryImpl(this.user);
        aclEntryImpl.permissionSet = (Vector)this.permissionSet.clone();
        aclEntryImpl.negative = this.negative;
        return aclEntryImpl;
    }
    
    public Principal getPrincipal() {
        return this.user;
    }
}
